@@ -6,4 +6,6 @@ from .datasets import load_dataset_numpy,load_dataset_pandas,load_image
 
 from .numpy import equals_vector,verificar_igualdad
 
-from .plot import plot_regresion_lineal,plot_regresion_lineal_univariada,plot_regresion_logistica2D,plot_loss
\ No newline at end of file
+from .plot import plot_regresion_lineal,plot_regresion_lineal_univariada,plot_regresion_logistica2D,plot_loss,plot_loss_accuracy
+
+from .plot_logistic import plot_regresion_logistica1d
\ No newline at end of file
