@@ -1,6 +1,7 @@
 import matplotlib.pyplot as plt
 from mpl_toolkits.mplot3d import Axes3D
 import numpy as np
+import matplotlib.patches as patches
 
 
 
@@ -22,6 +23,18 @@ def plot_regresion_lineal_univariada(w,b,x,y,x_label,y_label,title=""):
     ax_data.set_ylabel(y_label)
 
 
+def add_legends(ax_data,mx,my,b,mean_error):
+    model = patches.Patch(color='red', label='Modelo: y=x1*{:.2f}+x2*{:.2f}+{:.2f}'.format(mx,my,b))
+    data = patches.Patch(color='blue', label='Datos')
+    handles=[model,data]
+    label='$E = \\frac{1}{n}  \sum_i^n E_i = $  %.2f' % (mean_error)
+    error_patch = patches.Patch(color='black', label=label)
+    handles.append(error_patch)
+    ax_data.legend(handles=handles,fontsize=8)
+
+def mean_error(w,b,x1,x2,y):
+    y_pred = w[0]*x1+w[1]*x2+b
+    return np.mean( (y_pred-y)**2)
 
 def plot_regresion_lineal(w,b,x1,x2,y,x1_label,x2_label,y_label,title=""):
     # genero una ventana de dibujo con una sola zona de dibujo (1,1)
@@ -54,7 +67,8 @@ def plot_regresion_lineal(w,b,x1,x2,y,x1_label,x2_label,y_label,title=""):
     ax_data.set_ylabel(x2_label)#"x2 (Promedio)")
     ax_data.set_zlabel(y_label)#"y (Nota)")
     # Establezco el titulo del grafico
-    ax_data.set_title(title)#"(Horas estudiadas x Promedio) vs Nota")
+    # ax_data.set_title(title)
+    add_legends(ax_data,w[0],w[1],b,mean_error(w,b,x1,x2,y))
 
 
 
@@ -80,7 +94,7 @@ def plot_regresion_logistica2D(modelo, x, y,title="",detail=0.1):
     plt.contourf(xx, yy, Z, alpha=0.3)  # ,  cmap='RdBu')
     plt.colorbar()
     plt.title(titulo)
-    
+
     # puntos con las clases
     plt.scatter(x[:, 0], x[:, 1], c=y)
 
@@ -92,3 +106,11 @@ def plot_loss(loss_history):
     plt.xlabel("Época")
     plt.ylabel("Error")
     
+
+def plot_loss_accuracy(loss_history,acc_history):
+    plt.figure()
+    epochs = np.arange(1,len(loss_history)+1)
+    plt.plot(epochs,loss_history)
+    plt.plot(epochs,acc_history)
+    plt.xlabel("Época")
+    plt.ylabel("Error/accuracy")
\ No newline at end of file
